//
//  BlockState.swift
//  HTMLStreamer
//
//  Created by Shadowfacts on 2/14/24.
//

import Foundation

protocol BlockRenderer {
    var blockState: BlockState { get set }
    mutating func insertBlockBreak()
}

extension BlockRenderer {
    mutating func startOrFinishBlock() {
        switch blockState {
        case .start:
            break
        case .nonEmptyBlock:
            blockState = .emptyBlock
        case .emptyBlock:
            break
        }
    }
    
    mutating func continueBlock() {
        switch blockState {
        case .start:
            blockState = .nonEmptyBlock
        case .nonEmptyBlock:
            break
        case .emptyBlock:
            insertBlockBreak()
            blockState = .nonEmptyBlock
        }
    }
    
}

enum BlockState: Equatable {
    case start
    case nonEmptyBlock
    case emptyBlock
}
